@@ -126,12 +126,9 @@ pub fn solve(
         (2016, 23, _) => to_stringer_input(year2016::day23::solve, &mut input),
         (2016, 24, _) => to_stringer_input(year2016::day24::solve, &mut input),
         (2016, 25, _) => to_stringer_input(year2016::day25::solve, &mut input),
-        (2017, 1, 1) => to_stringer(year2017::day01::part1, input_string),
-        (2017, 1, 2) => to_stringer(year2017::day01::part2, input_string),
-        (2017, 2, 1) => to_stringer(year2017::day02::part1, input_string),
-        (2017, 2, 2) => to_stringer(year2017::day02::part2, input_string),
-        (2017, 3, 1) => to_stringer(year2017::day03::part1, input_string),
-        (2017, 3, 2) => to_stringer(year2017::day03::part2, input_string),
+        (2017, 1, _) => to_stringer_input(year2017::day01::solve, &mut input),
+        (2017, 2, _) => to_stringer_input(year2017::day02::solve, &mut input),
+        (2017, 3, _) => to_stringer_input(year2017::day03::solve, &mut input),
         (2017, 4, _) => to_stringer_input(year2017::day04::solve, &mut input),
         (2017, 5, 1) => to_stringer(year2017::day05::part1, input_string),
         (2017, 5, 2) => to_stringer(year2017::day05::part2, input_string),
@@ -242,8 +239,7 @@ pub fn solve(
         (2019, 17, 1) => to_stringer(year2019::day17::part1, input_string),
         (2019, 17, 2) => to_stringer(year2019::day17::part2, input_string),
         (2019, 18, _) => to_stringer_input(year2019::day18::solve, &mut input),
-        (2019, 19, 1) => to_stringer(year2019::day19::part1, input_string),
-        (2019, 19, 2) => to_stringer(year2019::day19::part2, input_string),
+        (2019, 19, _) => to_stringer_input(year2019::day19::solve, &mut input),
         (2019, 20, 1) => to_stringer(year2019::day20::part1, input_string),
         (2019, 20, 2) => to_stringer(year2019::day20::part2, input_string),
         (2019, 21, 1) => to_stringer(year2019::day21::part1, input_string),
